<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 * @author     Your Name <email@example.com>
 */
class Skype_Plugin_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/skype-plugin-admin.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/skype-plugin-admin.js', array( 'jquery' , 'wp-color-picker' ), $this->version, false );
	}
	
	public function sp_admin_menu_fn() {
		add_options_page('Skype Chitchat','Skype Chitchat','manage_options','skype_plugin_slug',array($this,'sp_load_menu_fn'));
	}
	
	public function sp_load_menu_fn() {
		require plugin_dir_path(__FILE__)."/partials/skype-plugin-admin-display.php";
	}
	
	public function sp_handle_post_request_fn(){
		if(isset($_POST['sp_form_submit_btn'])){
			$array = [];
			$array['sp_skype_id'] = $_POST['sp_skype_id'];
			$array['sp_btn_style'] = $_POST['sp_btn_style'];
			$array['sp_btn_clr'] = $_POST['sp_btn_clr'];
			$array['sp_msg_clr'] = $_POST['sp_msg_clr'];
			$array['sp_btn_lbl'] = $_POST['sp_btn_lbl'];
			$array['sp_data_theme'] = $_POST['sp_data_theme'];
			$array['sp_data_can_collapse'] = $_POST['sp_data_can_collapse'];
			$array['sp_data_can_close'] = $_POST['sp_data_can_close'];
			$array['sp_data_can_upload_file'] = $_POST['sp_data_can_upload_file'];
			$array['sp_data_show_header'] = $_POST['sp_data_show_header'];
			$array['sp_data_entry_animation'] = $_POST['sp_data_entry_animation'];
			$array['sp_Show_all'] = $_POST['sp_Show_all'];
			$array['sp_select_page'] = isset($_POST['sp_select_page'])?$_POST['sp_select_page']:array();
			$array['sp_select_post'] = isset($_POST['sp_select_post'])?$_POST['sp_select_post']:array();
			$array_json = json_encode($array);
			$result = update_option('skype_pulgin_setting_save', $array_json );
			if($result){
				update_option('sp_save_changes' , '1');
			}
		}
	}
}